@@ -69,6 +69,8 @@
 #include <jwhois.h>
 #include <cache.h>
 
+#include <string.h>
+
 #ifdef ENABLE_NLS
 # include <libintl.h>
 # define _(s)  gettext(s)
@@ -159,7 +161,7 @@ cache_init(void)
   if (iret < 0)
     {
       if (verbose) printf("[Cache: %s]\n",
-			  _("Unable to store data in cache]\n"));
+			  _("Unable to store data in cache\n"));
       cache = 0;
     }
   dbm_close(dbf);
