@@ -66,7 +66,7 @@ int
 main(int argc, char **argv)
 {
   int optind, count = 0, ret;
-  char *qstring = NULL, *text;
+  char *qstring = NULL, *text, *cachestr;
   struct s_whois_query wq;
 
 #ifdef ENABLE_NLS
@@ -133,7 +133,15 @@ main(int argc, char **argv)
 #ifndef NOCACHE
   if (!forcelookup && cache) {
     if (verbose>1) printf("[Looking up entry in cache]\n");
-    ret = cache_read(wq.query, &text);
+    cachestr = malloc(strlen(wq.query) + strlen(wq.host) + 1);
+    if (!cachestr)
+      {
+        printf("[%s]\n", _("Error allocating memory"));
+        exit(1);
+      }
+    snprintf(cachestr, strlen(wq.query) + strlen(wq.host) + 1, "%s:%s",
+             wq.host, wq.query);
+    ret = cache_read(cachestr, &text);
     if (ret < 0)
       {
 	printf("[%s]\n", _("Error reading cache"));
@@ -152,7 +160,7 @@ main(int argc, char **argv)
 #ifndef NOCACHE
   if (cache) {
     if (verbose>1) printf("[Storing in cache]\n");
-    ret = cache_store(wq.query, text);
+    ret = cache_store(cachestr, text);
     if (ret < 0)
       {
 	printf("[%s]\n", _("Error writing to cache"));
@@ -182,8 +190,7 @@ jwhois_query(struct s_whois_query *wq, char **text)
   
   if (!raw_query)
     {
-      oldquery = malloc(strlen(wq->query)+1);
-      strncpy(oldquery, wq->query, strlen(wq->query)+1);
+      oldquery = wq->query;
       wq->query = (char *)lookup_query_format(wq);
     }
 
@@ -207,7 +214,10 @@ jwhois_query(struct s_whois_query *wq, char **text)
     }
 
   if (!raw_query)
-    wq->query = oldquery;
+    {
+      free(wq->query);
+      wq->query = oldquery;
+    }
 
   if (ret < 0)
     {
@@ -215,9 +225,7 @@ jwhois_query(struct s_whois_query *wq, char **text)
     }
   if (ret > 0)
     {
-      int rc = jwhois_query(wq, text);
-      free(wq->query);
-      return rc;
+      return jwhois_query(wq, text);
     }
   else
     return 0;
